==> ejc-riskmortgage-api-3.0.0-20231129.072737-95-sources.jar: com/ejianc/business/share/vo/ShareOrgVO.java <==
package com.ejianc.business.share.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分配-直管部分配明细
 * 
 * @author generator
 * 
 */
public class ShareOrgVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long shareId; // 主表id
    private Long payerId; // 员工表主键id
    private String payerCode; // 员工明细编号
    private Long payerDetailId; // 员工明细表主键id
    private String name; // 姓名
    private String job; // 角色
    private String phone; // 手机号
    private BigDecimal payerMny; // 缴纳金额（万元）
    private BigDecimal payerScale; // 实际纳金额占比
    private BigDecimal actualPayerMny; // 实际已缴纳金额（万元）
    private BigDecimal shareOrgMny; // 分配金额（万元）
    private BigDecimal shareOrgScale; // 分配金额占比
    private String memo; // 备注
    

    public Long getShareId() {
        return shareId;
    }

    public void setShareId(Long shareId) {
        this.shareId = shareId;
    }
    public Long getPayerId() {
        return payerId;
    }

    public void setPayerId(Long payerId) {
        this.payerId = payerId;
    }
    public String getPayerCode() {
        return payerCode;
    }

    public void setPayerCode(String payerCode) {
        this.payerCode = payerCode;
    }
    public Long getPayerDetailId() {
        return payerDetailId;
    }

    public void setPayerDetailId(Long payerDetailId) {
        this.payerDetailId = payerDetailId;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getJob() {
        return job;
    }

    public void setJob(String job) {
        this.job = job;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public BigDecimal getPayerMny() {
        return payerMny;
    }

    public void setPayerMny(BigDecimal payerMny) {
        this.payerMny = payerMny;
    }
    public BigDecimal getPayerScale() {
        return payerScale;
    }

    public void setPayerScale(BigDecimal payerScale) {
        this.payerScale = payerScale;
    }
    public BigDecimal getActualPayerMny() {
        return actualPayerMny;
    }

    public void setActualPayerMny(BigDecimal actualPayerMny) {
        this.actualPayerMny = actualPayerMny;
    }
    public BigDecimal getShareOrgMny() {
        return shareOrgMny;
    }

    public void setShareOrgMny(BigDecimal shareOrgMny) {
        this.shareOrgMny = shareOrgMny;
    }
    public BigDecimal getShareOrgScale() {
        return shareOrgScale;
    }

    public void setShareOrgScale(BigDecimal shareOrgScale) {
        this.shareOrgScale = shareOrgScale;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-riskmortgage-api-3.0.0-20231207.081745-117-sources.jar: com/ejianc/business/share/vo/ShareOrgVO.java <==
package com.ejianc.business.share.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分配-直管部分配明细
 * 
 * @author generator
 * 
 */
public class ShareOrgVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long shareId; // 主表id
    private Long payerId; // 员工表主键id
    private String payerCode; // 员工明细编号
    private Long payerDetailId; // 员工明细表主键id
    private String name; // 姓名
    private String job; // 角色
    private String phone; // 手机号
    private BigDecimal payerMny; // 缴纳金额（万元）
    private BigDecimal payerScale; // 实际纳金额占比
    private BigDecimal actualPayerMny; // 实际已缴纳金额（万元）
    private BigDecimal shareOrgMny; // 分配金额（万元）
    private BigDecimal shareOrgScale; // 分配金额占比
    private String memo; // 备注
    private Long employeeId; // 人员id

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public Long getShareId() {
        return shareId;
    }

    public void setShareId(Long shareId) {
        this.shareId = shareId;
    }
    public Long getPayerId() {
        return payerId;
    }

    public void setPayerId(Long payerId) {
        this.payerId = payerId;
    }
    public String getPayerCode() {
        return payerCode;
    }

    public void setPayerCode(String payerCode) {
        this.payerCode = payerCode;
    }
    public Long getPayerDetailId() {
        return payerDetailId;
    }

    public void setPayerDetailId(Long payerDetailId) {
        this.payerDetailId = payerDetailId;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getJob() {
        return job;
    }

    public void setJob(String job) {
        this.job = job;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public BigDecimal getPayerMny() {
        return payerMny;
    }

    public void setPayerMny(BigDecimal payerMny) {
        this.payerMny = payerMny;
    }
    public BigDecimal getPayerScale() {
        return payerScale;
    }

    public void setPayerScale(BigDecimal payerScale) {
        this.payerScale = payerScale;
    }
    public BigDecimal getActualPayerMny() {
        return actualPayerMny;
    }

    public void setActualPayerMny(BigDecimal actualPayerMny) {
        this.actualPayerMny = actualPayerMny;
    }
    public BigDecimal getShareOrgMny() {
        return shareOrgMny;
    }

    public void setShareOrgMny(BigDecimal shareOrgMny) {
        this.shareOrgMny = shareOrgMny;
    }
    public BigDecimal getShareOrgScale() {
        return shareOrgScale;
    }

    public void setShareOrgScale(BigDecimal shareOrgScale) {
        this.shareOrgScale = shareOrgScale;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
